/* This include file contains general constants used throughout the usecode. Constants particular to a function can (usually) be found in the relevant codefile. */

#include "constants/npc_constants.uc";		//NPC-specific constants (names, properties and flags)
#include "constants/shape_constants.uc";	//shapes and frames
#include "constants/global_flags.uc";		//global flags

//Wildcards (used for specifying "any acceptable value for this parameter" to a measuring function)
enum wildcards
{
	SHAPE_ANY	= -359,
	QUALITY_ANY	= -359,
	FRAME_ANY	= -359
};

//tick multipliers, for use with UI_advance_time()
/*
e.g.:
UI_advance_time(2 * HOUR);		//advance time by two hours
UI_advance_time(30 * MINUTE);	//advance time by 30 minutes
*/
enum times
{
	MINUTE	= 25,
	HOUR	= 1500
};

//Event types
enum events
{
	PROXIMITY	= 0,	//Object is on-screen or nearby (called every N seconds)
	DOUBLECLICK	= 1,	//Object is double-clicked on
	SCRIPTED	= 2,	//Scripted event (triggered by usecode)
	EGG			= 3,	//Egg event (triggered by egg activation parameters)
	WEAPON		= 4		//Object is used as a weapon
};

//Coordinate axes - use when referencing x,y,z arrays
enum axes
{
	X = 1,	//horizontal axis (numbered from west to east)
	Y = 2,	//vertical axis (numbered from north to south)
	Z = 3	//lift axis (numbered from ground to sky)
};

//Cardinal directions, taken from documentation
enum directions
{
	NORTH		= 0,
	NORTHEAST	= 1,
	EAST		= 2,
	SOUTHEAST	= 3,
	SOUTH		= 4,
	SOUTHWEST	= 5,
	WEST		= 6,
	NORTHWEST	= 7
};

//parts of the day (3-hour intervals)
enum day_periods
{
	MIDNIGHT		= 0,	//0-2
	EARLY			= 1,	//3-5
	DAWN			= 2,	//6-8
	MORNING			= 3,	//9-11
	NOON			= 4,	//12-14
	AFTERNOON		= 5,	//15-17
	EVENING			= 6,	//18-20
	NIGHT			= 7		//21-23
};

//Item/NPC flags, stolen from the Exult LB-joins-party patch with some comments added
//These can be retrieved and set using UI_get_item_flag(itemref, flag), UI_set_item_flag(itemref, flag) and UI_clear_item_flag(itemref, flag).
enum item_flags
{
	INVISIBLE			= 0,
	ASLEEP				= 1,
	CHARMED				= 2,
	CURSED				= 3,
	DEAD				= 4,
	IN_PARTY			= 6,
	PARALYZED			= 7,
	POISONED			= 8,
	PROTECTION			= 9,
	ON_MOVING_BARGE		= 10,		// ??Guessing.
	OKAY_TO_TAKE		= 11,		// This likely means that the item does not belong to anyone.
	MIGHT				= 12,		// Double strength, dext, intel.
	NO_SPELL_CASTING	= 13,
	CANT_DIE			= 14,		// Test flag in monster_info.
	DANCING				= 15,		// ??Not sure.
	DONT_MOVE			= 16,		// In SI, user can't move. in BG, they're completely invisible.
	SI_ON_MOVING_BARGE	= 17,		// SI's version of 10?
	TEMPORARY			= 18,		// Is temporary - this likely means that the item will be deleted once 
									// the party leaves the superchunk (or picks the item up)
	OKAY_TO_LAND		= 21,		// Used for flying-carpet.
	IN_DUNGEON			= 23,		// Pretty sure. if set, you won't be accused of stealing food.
	CONFUSED			= 25,		// ??Guessing.
	IN_MOTION			= 26,		// ??Guessing (cart, boat)??
	MET					= 28,		// Has the npc been met - originally this was SI-only, but Exult implements it for BG too.
									// BG originally used global flags for this, but only for important NPCs. What a waste of time.
	SI_TOURNAMENT		= 29,		// SI-call usecode (eventid = 7)
	SI_ZOMBIE			= 30,		// Used for sick neyobi.

	//Flags > 31 appear to be SI flags only
	POLYMORPH	= 32,		// SI.  pretty sure about this.
	TATTOOED	= 33,		// guess (SI).
	READ		= 34,		// guess (SI).
	PETRA		= 35,		// guess
	FREEZE		= 37		// SI.  pretty sure.
};