/* This include file contains scripts relating to NPCs */


/* NPC-specific external functions */

extern var isNearby 0x8F7(var npc);		//returns true if the specified NPC is nearby the player and not asleep
extern var nearEachOther 0x8FC(var npc1, var npc2);	//returns true if one NPC is nearby the other (within 20 units)

extern var getPoliteTitle 0x909();		//returns "milord" or "milady", depending on the gender of the player

extern var askYesNo 0x90A();			//asks a Yes/No question in a conversation; returns true/false respectively
extern scheduleBarks 0x92E(var npc);	//responsible for general wandering-around schedule-related barks (e.g. snoring, uttering Fellowship epithets, commenting on the weather, etc.) Accepts either an NPC number or an actual object reference

extern askAboutFellowship 0x919();		//generic Fellowship spiel ("An organisation of spiritual seekers...")


/* New (or reimplemented) NPC functions */

//Checks whether the player is carrying the cubic prism (for truthtelling situations)
var hasCube 0xC00()
{
	var cube = UI_get_cont_items(UI_get_avatar_ref(), SHAPE_PRISM, QUALITY_ANY, FRAME_CUBE);
	if (cube) return true; else return false;
}

//use during script sequences, to prevent the actor from moving according to schedule or player input
var freeze 0xC01()		{ UI_set_item_flag(item, PARALYZED); }
var unfreeze 0xC02()	{ UI_clear_item_flag(item, PARALYZED); }

//until proper function pointers are implemented for scripts...
const int func_freeze	= 0xC01;
const int func_unfreeze	= 0xC02;


//Called when the player asks a fellowship member about 'philosophy'.
//Tweaked to add in some cleverness the second time the player asks someone, and also some extra behaviour when the player has the cube.

//global flag used for checking if the player has heard this bollocks already
askAboutPhilosophy 0x91A ()
{
	var avatar = UI_get_avatar_ref();

	if (hasCube())
	{
		//a lot of these NPCs don't even use this function; so far the only ones that do are Klog and Rankin. That's why we can get away with using 'he'.
		var knowing_npcs = [KLOG, ELYNOR, SINTAG, GORDY, RANKIN, DANAG];

		if (UI_get_npc_number(item) in knowing_npcs)
		{
			item->say("The cube vibrates. \"Our philosophy is a collection of self-serving doctrines used to muddy the minds of the weak and justify any immoral acts my superiors set their minds to.~I think it's worked rather well, don't you?\" He beams at you obliviously.");
		}
		else
		{
			item->say("The cube vibrates. \"Hmmm...to be honest it all seems like a load of twaddle, now that I think about it. Perhaps I shan't bore you with it after all!\"");
		}
	}
	else
	{
		if (!gflags[HEARD_PHILOSOPHY])
		{
			item->say("\"The Fellowship advances the philosophy of 'sanguine cognition', a way to apply a confident order of thought to one's life, through what is called the Triad of Inner Strength. The Triad is simply three basic principles that, when applied in unison, enable one to be more creative, satisfied, and successful in life. They are: Strive For Unity, Trust Thy Brother, and Worthiness Precedes Reward. Strive For Unity basically means that people should cooperate and work together. Trust Thy Brother implies that we are all the same and that we should not hate or fear each other. Worthiness Precedes Reward suggests that we must each strive to be worthy of that which we want out of life.\"");
			gflags[HEARD_PHILOSOPHY] = true;
		}
		else
		{
			item->hide();
			avatar->say("You immediately regret asking, as they embark on the same creepily well-rehearsed speech you've heard before. Your eyes glaze over and your thoughts wander, until with relief you hear them finish.");
			avatar->hide();
		}

		//finally, they notice the medallion
		if (UI_wearing_fellowship())
		{
			item->say("\"Oh! I just now noticed thy medallion! Thou dost already know all of this! Thou art one of us! Excuse me for going on and on about it!\"");
		}
		else
		{
			item->say("\"Dost thou want to join?\"");

			if (askYesNo()) say("\"Then thou shouldst go immediately to see Batlin at the Fellowship Hall headquarters in Britain.\"");
			else say("\"Oh. Well, perhaps thou canst become enlightened another time.\"");
		}
	}
}